/*******************************************************************************
 * Copyright (c) 2006, 2012 Oracle and/or its affiliates. All rights reserved.
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v1.0 and Eclipse Distribution License v. 1.0
 * which accompanies this distribution.
 * The Eclipse Public License is available at http://www.eclipse.org/legal/epl-v10.html
 * and the Eclipse Distribution License is available at
 * http://www.eclipse.org/org/documents/edl-v10.php.
 *
 * Contributors:
 *     Oracle - initial API and implementation
 *
 ******************************************************************************/
package org.eclipse.persistence.tools.mapping.orm;

import org.eclipse.persistence.tools.utility.iterable.ListIterable;


/**
 * This interface and inherited behavior describe all of the configurable properties defined for a
 * one-to-one mapping in the ORM xml. A mapping may be defined in the attributes section of the ORM xml.
 * <p>
 * Provisional API: This interface is part of an interim API that is still under development and
 * expected to change significantly before reaching stability. It is available at this early stage
 * to solicit feedback from pioneering adopters on the understanding that any code that uses this
 * API will almost certainly be broken (repeatedly) as the API evolves.<p>
 *
 * @see javax.persistence.OneToOne
 * @see http://jcp.org/aboutJava/communityprocess/final/jsr220/index.html, persistence specificaton
 *
 * @version 2.5
 * @author John Bracken
 */
public interface ExternalOneToOneMapping extends ExternalManyToOneMapping,
                                                 ExternalPrivatelyOwnableMapping,
                                                 ExternalOrphanRemovableMapping {

	/**
	 * Adds a primary key join column with the given name at the specified location.
	 */
	void addPrimaryKeyJoinColumn(int index, String name);

	/**
	 * Returns the primary key join column at the given position.
	 */
	ExternalPrimaryKeyJoinColumn getPrimaryKeyJoinColumn(int index);

	/**
	 * Returns a list of all primary key join column associations defined for this mapping.
	 */
	ListIterable<ExternalPrimaryKeyJoinColumn> primaryKeyJoinColumns();

	/**
	 * Returns the count of primary key join columns associations defined for this mapping.
	 */
	int primaryKeyJoinColumnsSize();

	/**
	 * Removes the primary key join column at the given position.
	 */
	void removePrimaryKeyJoinColumn(int index);
}